﻿// MainForm.cs
//
//  Copyright (C) 2009 Mawerick
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; version 2 of the License.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
//
using System;
using System.Drawing;
using System.IO;
using System.Windows.Forms;
using System.Xml;

using TWP.Utilities;

namespace GUISelect
{
	public partial class MainForm : Form
	{
		public MainForm()
		{
			InitializeComponent();
		}

		internal void OnLoad( object sender, EventArgs e )
		{
			Settings.Load();
			this.UpdatePath( Settings.AOPath );
			this.SetSkinBox.Checked = Settings.SetSkin;
		}

		internal void OnClosing( object sender, FormClosingEventArgs e )
		{
			Settings.Save();
		}

		internal void OnAbout( object sender, EventArgs e )
		{
			AboutBox about = new AboutBox();
			about.ShowDialog();
			about.Dispose();
		}

		internal void OnSave( object sender, EventArgs e )
		{
			this.SaveGUI();
			Application.Exit();
		}

		internal void OnBrowsePath( object sender, EventArgs e )
		{
			if( !String.IsNullOrEmpty( Settings.AOPath ) )
				this.AOPathBrowserDialog.SelectedPath = Settings.AOPath;
			DialogResult r = this.AOPathBrowserDialog.ShowDialog();
			if( r == DialogResult.OK )
			{
				this.UpdatePath( this.AOPathBrowserDialog.SelectedPath );
			}
		}

		internal void OnGUIChange(object sender, EventArgs e)
		{
			Settings.GUIName = this.GUIList.SelectedItem.ToString();
		}

		internal void OnSetSkinChanged( object sender, EventArgs e )
		{
			Settings.SetSkin = this.SetSkinBox.Checked;
		}

		internal void UpdatePath( string path )
		{
			if( !File.Exists( path + "\\version.id" ) )
			{
				Log.Warning( "The selected folder is not a valid Anarchy Online installation." );
				this.AOPathEntry.Text = "**Error**";
				return;
			}

			if( Settings.AOPath != path )
				Settings.AOPath = path;
			this.AOPathEntry.Text = path;

			path += "\\cd_image\\gui";
			this.GUIList.Items.Clear();
			DirectoryInfo dir = new DirectoryInfo( path );
			foreach( DirectoryInfo sub in dir.GetDirectories() )
			{
				this.GUIList.Items.Add( sub.Name );
			}
			if( this.GUIList.Items.Count > 1 )
			{
				this.GUIBox.Enabled = true;
				this.SaveButton.Enabled = true;
			}
			else
			{
				this.GUIBox.Enabled = false;
				this.SaveButton.Enabled = false;
			}
			this.LoadGUI();
		}

		internal void UpdateGUI( string GUI )
		{
			Log.Debug( "[Main] [UpdateGUI]", "GUI: " + GUI );
			if( this.GUIList.Items.Contains( GUI ) )
				this.GUIList.SelectedItem = GUI;
			else
				this.GUIList.SelectedItem = "Default";
		}

		internal void LoadGUI()
		{
			string fileName = Settings.AOPath + "\\Prefs\\Prefs.xml";
			if( !File.Exists( fileName ) )
				return;

			XmlDocument doc = new XmlDocument();
			try
			{
				doc.Load( fileName );
			}
			catch( FileNotFoundException ex )
			{
				Log.Debug( "[Main] [LoadGUI]", ex.Message );
				return;
			}

			XmlNodeList nodes = doc.GetElementsByTagName( "Value" );
			for( int i = 0; i < nodes.Count; ++i )
			{
				XmlAttributeCollection ac = nodes[i].Attributes;
				XmlAttribute name = ac["name"];
				if( name.Value == "GUIName" )
				{
					XmlAttribute value = ac["value"];
					this.UpdateGUI( value.Value.Trim( new char[] { '"' } ) );
					break;
				}
			}
		}

		internal void SaveGUI()
		{
			string fileName = Settings.AOPath + "\\Prefs\\Prefs.xml";
			if( !File.Exists( fileName ) )
				return;

			XmlDocument doc = new XmlDocument();
			try
			{
				doc.Load( fileName );
			}
			catch( FileNotFoundException ex )
			{
				Log.Debug( "[Main] [SaveGUI]", ex.Message );
				try
				{
					Log.Debug( "[Main] [SaveGUI]", "Trying to load default prefs..." );
					doc.Load( Settings.AOPath + "\\cd_image\\gui\\Default\\MainPrefs.xml" );
				}
				catch( FileNotFoundException ex2 )
				{
					Log.Debug( "[Main] [SaveGUI]", ex2.Message );
					return;
				}
			}

			XmlNodeList nodes = doc.GetElementsByTagName( "Value" );
			for( int i = 0; i < nodes.Count; ++i )
			{
				XmlAttributeCollection ac = nodes[i].Attributes;
				XmlAttribute name = ac["name"];
				if( name.Value == "GUIName" )
				{
					XmlAttribute value = ac["value"];
					value.Value = "\"" + Settings.GUIName + "\"";
				}
				if( name.Value == "GUISkin" && Settings.SetSkin == true )
				{
					string skin = ReadGUISkin();
					if( !String.IsNullOrEmpty( skin ) )
					{
						XmlAttribute value = ac["value"];
						value.Value = "\"" + skin + "\"";
					}
				}
			}
			doc.Save( fileName );
		}

		internal static string ReadGUISkin()
		{
			XmlDocument doc = new XmlDocument();
			try
			{
				doc.Load( Settings.AOPath + "\\cd_image\\gui\\" + Settings.GUIName + "\\MainPrefs.xml" );
			}
			catch( FileNotFoundException ex )
			{
				Log.Debug( "[Main] [ReadGUISkin]", ex.Message );
				return null;
			}

			string skin = null;
			XmlNodeList nodes = doc.GetElementsByTagName( "Value" );
			for( int i = 0; i < nodes.Count; ++i )
			{
				XmlAttributeCollection ac = nodes[i].Attributes;
				XmlAttribute name = ac["name"];
				if( name.Value == "GUISkin" )
				{
					XmlAttribute value = ac["value"];
					skin = value.Value.Trim( new char[] { '"' } );
					break;
				}
			}
			Log.Debug( "[Main] [ReadGUISkin]", "Skin: " + skin );
			if( !String.IsNullOrEmpty( skin ) )
			{
				FileInfo skinInfo = new FileInfo( Settings.AOPath + "\\cd_image\\" + skin );
				skin = skinInfo.FullName;
			}
			if( !File.Exists( skin ) )
				skin = null;
			return skin;
		}
	}
}
